# Global Flags

| Flag              | Description                    |
|-------------------|--------------------------------|
| `--config <path>` | Override config file location  |
| `--json`          | Output in JSON format          |
| `--quiet`         | Suppress info/warnings         |
| `--version`       | Show version                   |
